summaryrefslogtreecommitdiffstats
path: root/openpgp/src/serialize/stream.rs
diff options
context:
space:
mode:
authorWiktor Kwapisiewicz <wiktor@metacode.biz>2020-04-21 16:55:04 +0200
committerWiktor Kwapisiewicz <wiktor@metacode.biz>2020-04-21 18:09:47 +0200
commitf1ae1baa4d1b2a52f490b4faaabea7bdf1029568 (patch)
tree58e2c57b07e40412486bf50caf71c670b399ba65 /openpgp/src/serialize/stream.rs
parent8af5e4357c7348fe231b70a0fbe19788137caaa3 (diff)
openpgp: Rename signature::Builder to signature::SignatureBuilder.
- Rename all calls to `Builder` with `SignatureBuilder`. - Fixes #481.
Diffstat (limited to 'openpgp/src/serialize/stream.rs')
-rw-r--r--openpgp/src/serialize/stream.rs12
1 files changed, 6 insertions, 6 deletions
diff --git a/openpgp/src/serialize/stream.rs b/openpgp/src/serialize/stream.rs
index a4d3f27f..598c213c 100644
--- a/openpgp/src/serialize/stream.rs
+++ b/openpgp/src/serialize/stream.rs
@@ -637,7 +637,7 @@ pub struct Signer<'a> {
signers: Vec<Box<dyn crypto::Signer + 'a>>,
intended_recipients: Vec<Fingerprint>,
detached: bool,
- template: signature::Builder,
+ template: signature::SignatureBuilder,
creation_time: Option<SystemTime>,
hash: crypto::hash::Context,
cookie: Cookie,
@@ -724,14 +724,14 @@ impl<'a> Signer<'a> {
where S: crypto::Signer + 'a
{
Self::with_template(inner, signer,
- signature::Builder::new(SignatureType::Binary))
+ signature::SignatureBuilder::new(SignatureType::Binary))
}
/// Creates a signer with a given signature template.
///
/// Signs the message with the given [`crypto::Signer`] like
/// [`Signer::new`], but allows more control over the generated
/// signatures. The given [`signature::Builder`] is used to
/// create all the signatures.
///
/// For every signature, the creation time is set to the current
@@ -744,7 +744,7 @@ impl<'a> Signer<'a> {
///
/// [`crypto::Signer`]: ../../crypto/trait.Signer.html
/// [`Signer::new`]: #method.new
- /// [`signature::Builder`]: ../../packet/signature/struct.Builder.html
+ /// [`signature::SignatureBuilder`]: ../../packet/signature/struct.Builder.html
/// [`Signer::creation_time`]: #method.creation_time
/// [`Signer::hash_algo`]: #method.hash_algo
/// [`Signer::add_intended_recipient`]: #method.add_intended_recipient
@@ -777,7 +777,7 @@ impl<'a> Signer<'a> {
/// let message = Message::new(&mut sink);
/// let message = Signer::with_template(
/// message, signing_keypair,
- /// signature::Builder::new(SignatureType::Text)
+ /// signature::SignatureBuilder::new(SignatureType::Text)
/// .add_notation("issuer@starfleet.command", "Jean-Luc Picard",
/// None, true)?)
/// // Further customize the `Signer` here.
@@ -790,7 +790,7 @@ impl<'a> Signer<'a> {
pub fn with_template<S, T>(inner: Message<'a>, signer: S, template: T)
-> Self
where S: crypto::Signer + 'a,
- T: Into<signature::Builder>,
+ T: Into<signature::SignatureBuilder>,
{
let inner = writer::BoxStack::from(inner);
let level = inner.cookie_ref().level + 1;
@@ -724,14 +724,14 @@ impl<'a> Signer<'a> {
/// Signs the message with the given [`crypto::Signer`] like
/// [`Signer::new`], but allows more control over the generated
- /// signatures. The given [`signature::Builder`] is used to
+ /// signatures. The given [`signature::SignatureBuilder`] is used to
/// create all the signatures.
///